/*
	File:		DropView.m

	Contains:	A sample to demonstrate Drag and Drop with Images in Cocoa

	Written by: 	KG

	Copyright:	Copyright � 2002 by Apple Computer, Inc., All Rights Reserved.

			You may incorporate this Apple sample source code into your program(s) without
			restriction. This Apple sample source code has been provided "AS IS" and the
			responsibility for its operation is yours. You are not permitted to redistribute
			this Apple sample source code as "Apple sample source code" after having made
			changes. If you're going to re-distribute the source, we require that you make
			it clear in the source that the code was descended from Apple sample source
			code, but that you've made changes.

	Change History (most recent first):
                        01/2002		initial version
*/
#import "DropView.h"
#import "NSObject+UUID.h"
#import "Controller.h"

#define firstFieldKey @"2704FAF1-1D2C-486D-954B-F4BCAD532778"

@implementation DropView

//Destination Operations

- (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)sender
{
	NSPasteboard *pboard = [sender draggingPasteboard];
    
    NSArray* types = [pboard types];
    
    if( ![types containsObject:NSFilenamesPboardType] )
        return NSDragOperationNone;
    
    NSArray *fileNames = [pboard propertyListForType:NSFilenamesPboardType];
    
    if( [fileNames count] != 1 )
        return NSDragOperationNone;

    NSFileManager* fileManager = [NSFileManager defaultManager];

    for( NSString* aFilePath in fileNames ) {
        
        if( [[aFilePath pathExtension] compare:@"pdf" options:NSCaseInsensitiveSearch] != NSOrderedSame )
            return NSDragOperationNone;
        
        NSDictionary* attributes = [fileManager attributesOfItemAtPath:aFilePath error:NULL];
        
        if( attributes == nil )
            return NSDragOperationNone;
        
        NSString* fileType = [attributes objectForKey:NSFileType];
                              
        if( ![fileType isEqualToString:NSFileTypeRegular] )
            return NSDragOperationNone;
    }
    
    _highlight = YES;
    [self setNeedsDisplay:YES];	// force hilite the drop area
	
    return NSDragOperationCopy;
}

- (void)draggingExited:(id <NSDraggingInfo>)sender
{
    /*------------------------------------------------------
       method called whenever a drag exits our drop zone
    --------------------------------------------------------*/
    _highlight = NO;//remove _highlight of the drop zone
    [self setNeedsDisplay:YES];
}

- (void)drawRect:(NSRect)rect
{
    /*------------------------------------------------------
        draw method is overridden to do drop highlighing
    --------------------------------------------------------*/
    [super drawRect:rect];//do the usual draw operation to display the image
    
    if( _highlight ) {
        //_highlight by overlaying a gray border
        [[NSColor grayColor] set];
        [NSBezierPath setDefaultLineWidth: 5];
        [NSBezierPath strokeRect: rect];
    }
}

- (BOOL)performDragOperation:(id<NSDraggingInfo>)sender
{
    _highlight = NO;//finished with the drag so remove any _highlighting
    [self setNeedsDisplay:YES];
    
    /*------------------------------------------------------
     method to determine if we can accept the drop
     --------------------------------------------------------*/
	NSPasteboard *pboard = [sender draggingPasteboard];
    NSArray *fileNames = [pboard propertyListForType:NSFilenamesPboardType];

    if( [fileNames count] != 1 )
        return NO;

    NSString* filePath = [fileNames objectAtIndex:0];
    NSSavePanel* savePanel = [NSSavePanel savePanel];
    
    NSString* folderPath = [filePath stringByDeletingLastPathComponent];
    
    NSLog(@"folderPath = %@", folderPath);
    [savePanel setDirectoryURL:[NSURL fileURLWithPath:folderPath]];
    
    NSString* newFilePath = [[filePath stringByDeletingPathExtension] stringByAppendingPathExtension:@"txt"];
    [savePanel setNameFieldStringValue:[newFilePath lastPathComponent]];
    
    [savePanel beginSheetModalForWindow:self.window completionHandler:^(NSInteger result) {
        
        if( result == NSFileHandlingPanelCancelButton )
            return;

        // extract text from pdf
        NSBundle* mainBundle = [NSBundle mainBundle];
        NSString* dylibPath = [mainBundle privateFrameworksPath];
        
        dylibPath = [dylibPath stringByAppendingPathComponent:@"libDebenuPDFLibraryDylib1015.dylib"];
        NSLog(@"== dylibPath = %@", dylibPath);
        
        Controller* controller = [[[Controller alloc] init] autorelease];
        NSError* error = nil;
        
        if( ![controller createTextFromPDF:filePath toPath:newFilePath error:&error] ) {
            
            NSAlert* alert = [NSAlert alertWithMessageText:[error localizedDescription]
                                             defaultButton:@"OK"
                                           alternateButton:nil
                                               otherButton:nil
                                 informativeTextWithFormat:@""];
            
            [alert runModal];
            return;
        }
    }];
     
    return YES;
}
     
@end
